padding property
padding inside country button,
this can be used to align the country button with the phone number
and is mostly useful when using isCountryButtonPersistent as true.
Implementation
final EdgeInsets? padding;
padding inside country button,
this can be used to align the country button with the phone number
and is mostly useful when using isCountryButtonPersistent as true.
final EdgeInsets? padding;